
#Done in the shell
# for i in /fh/fast/tapscott_s/SR/ngs/illumina/aspens/201203_VH00319_17_AAAHTTTM5/Unaligned/Project_aspens/*.fastq.gz; do trim_galore --fastqc --fastqc_args "--outDir /fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/fastqc/" -o /fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/ --illumina --gzip $i; done

# Done in R
library(DESeq2)
library(tidyverse)


setwd("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/")

fastqs <- list.files(path = "/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/", pattern = "*R1.fastq.gz")

for(i in 1:length(fastqs))  {
  print(fastqs[i])
  align(index = "/fh/fast/tapscott_s/CompBio/genome_reference/GRCh38/Sequence/SubreadIndex/subread_GRCh38.p13", 
        readfile1 = paste0("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/", fastqs[i]), 
        readfile2 = paste0("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/trimmed_fastqs/", gsub("R1_001.fastq.gz", "R2_001.fastq.gz", fastqs[i])), 
        type = "rna", nthreads = 10, output_format = "bam", sortReadsByCoordinates = TRUE)
}

library(Rsubread)

setwd("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/bams/")

bam_files <- list.files(pattern = "*.bam", path ="/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/bams/")
bai_files <- list.files(pattern = "*.bai", path ="/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/bams/")

bam_files <- setdiff(bam_files, bai_files)

LongCTD_bams <- bam_files[1:9]
F67A_bams <- fastqs[10:18]

F67A_data <- featureCounts(files = bam_files, annot.ext = "/fh/fast/tapscott_s/CompBio/genome_reference/GRCh38/Annotation/gencode.v35.annotation.gtf", isGTFAnnotationFile = TRUE, GTF.attrType = "gene_id", nthreads = 3)

LongCTD_data <- featureCounts(files = bam_files, annot.ext = "/fh/fast/tapscott_s/CompBio/genome_reference/GRCh38/Annotation/gencode.v35.annotation.gtf", isGTFAnnotationFile = TRUE, GTF.attrType = "gene_id", nthreads = 3)

write.csv(F67A_data$counts, "/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/F67A_raw_counts.csv")
write.csv(LongCTD_data$counts, "/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/LongCTD_raw_counts.csv")


F67A_sampleInfo <- read.csv("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/F67A_sampleSheet.csv")

F67A_data <- read.csv("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/F67A_raw_counts.csv", header = TRUE)
rownames(F67A_data) <- F67A_data$X

F67A_data <- F67A_data[,2:10]
F67A_data_cleaned <- F67A_data[rowSums(F67A_data) > 10,]

F67A_dds_gene <- DESeqDataSetFromMatrix(countData = F67A_data_cleaned, colData = F67A_sampleInfo, design = ~ pheno_type)


F67A_gene_PCA <- plotPCA(rlog(F67A_dds_gene), intgroup = "pheno_type")

F67A_dds_gene_2 <- DESeq(F67A_dds_gene)
F67A_res_gene <- results(F67A_dds_gene_2)

write.csv(F67A_res_gene, "/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/F67A_RNAseq_gene_level.csv")


#LongCTD

LongCTD_sampleInfo <- read.csv("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/LongCTD_sampleSheet.csv")

LongCTD_data <- read.csv("/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/LongCTD_raw_counts.csv", header = TRUE)
rownames(LongCTD_data) <- LongCTD_data$X

LongCTD_data <- LongCTD_data[,2:10]
LongCTD_data_cleaned <- LongCTD_data[rowSums(LongCTD_data) > 10,]

LongCTD_dds_gene <- DESeqDataSetFromMatrix(countData = LongCTD_data_cleaned, colData = LongCTD_sampleInfo, design = ~ pheno_type)


LongCTD_gene_PCA <- plotPCA(rlog(LongCTD_dds_gene), intgroup = "pheno_type")

LongCTD_dds_gene_2 <- DESeq(LongCTD_dds_gene)
LongCTD_res_gene <- results(LongCTD_dds_gene_2)

write.csv(LongCTD_res_gene, "/fh/fast/tapscott_s/user/sbennett/AES_RNA-Seq/LongCTD_RNAseq_gene_level.csv")

